<?php
session_start();
require_once('../inc/tumblroauth.php');
require_once('../inc/config.php');
require_once('../inc/process_class.php');
require_once('../inc/ChromePhp.php');
require_once('../inc/DB.php');

/* If access tokens are not available redirect to connect page. */
if (empty($_SESSION['access_token']) || empty($_SESSION['access_token']['oauth_token']) || empty($_SESSION['access_token']['oauth_token_secret'])) {
  header('Location: ../inc/redirect.php');
}

$db     = DB::getInstance();
$mysqli = $db->getConnection();

ChromePhp::log('Started');
ChromePhp::log('DB Connect');

if (mysqli_connect_errno()) {
  printf("Connect failed: %s\n", mysqli_connect_error());
  exit();
}

$errors = array();
$data   = array();
$result = array();

$access_token   = $_SESSION['access_token'];

$post_interval  = intval($_POST['qinterval']);
$post_repeat    = intval($_POST['repeat']);
$queue_status   = "active";
$blogname       = $_POST['blogname'];

$queuename      = str_replace(" ", "", $_POST['queuename']);
$queuename      = str_replace("-", "", $queuename);

if ( isset($_SESSION['userblog']) && $_SESSION['userblog'] !== '')
  $username     = $_SESSION['userblog'];
else
  $username     = "";

if (isset($_POST['fromBlogs'])) {
  $post_fromblogs = $_POST['fromBlogs'];
  foreach($_POST['fromBlogs'] as $post_fromblogs) {
    $url    = str_replace("https://", "", $post_fromblogs);
    $url    = str_replace("https://", "", $url);
    $pieces = explode("/", $url);
    if( isset($pieces[2]) ) {
      $blogurls  = $pieces[0];
      $str       = explode(".", $blogurls);
      $postid    = $pieces[2];
      $blogurl   = $str[0];
    
      $requestlink = 'https://api.tumblr.com/v2/blog/' . $blogurl . '.tumblr.com/posts?id=' . $postid . '&api_key=' . CONSUMER_KEY;

      $ch = curl_init($requestlink);
      curl_setopt($ch, CURLOPT_HEADER, 0);
      curl_setopt($ch, CURLOPT_POST, 0);
      curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
      $collection = json_decode(curl_exec($ch), true);
      curl_close($ch);

      if ( isset($collection['meta']) && ($collection['meta']['msg'] == 'OK') ) {
        array_push($result, $collection['response']['posts'][0]);
      } else {
        array_push($errors, $collection['meta']['msg']);
      }
    } else {
      array_push($errors, "Invalid blog name. Please input the full blog url to post");
    }
  }

  if (!empty($result)) {
    $query = "SELECT `queuename` FROM `queues` WHERE queuename=?";
    
    if ($stmt = $mysqli->prepare($query)) {
      $stmt->bind_param("s", $queuename);
  
      if($stmt->execute()) {
          $stmt->store_result();
          $squeue_check= "";         
          $stmt->bind_result($squeue_check);
          $stmt->fetch();
  
          if ($stmt->num_rows != 1) {
            $post_notecount = 0;
            $posts_since    = "";
            $mode           = "new";
            $tag            = "";
  
            $mysqli->query("CREATE TABLE IF NOT EXISTS $queuename (id INT NOT NULL AUTO_INCREMENT PRIMARY KEY, oauth_token VARCHAR(100), oauth_token_secret VARCHAR(100), 
                post_interval INT, blogname VARCHAR(100), postid VARCHAR(50), reblog_key VARCHAR(50),type VARCHAR(10), notecount INT, state VARCHAR(15), title VARCHAR(100),
                body longtext, caption TEXT, external_url TEXT, embed longtext, quote TEXT, source TEXT, url TEXT, thumbnail TEXT, description TEXT, author TEXT,
                excerpt TEXT, conversation longtext,link TEXT ) ENGINE=InnoDB");
        
            $stmt = $mysqli->prepare("INSERT INTO queues (queuename, username, toblog, fromblog, queued_tag, notecount, posts_since, queue_interval, status) VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?)");
            $stmt->bind_param('sssssdsds', $queuename, $username, $blogname, $post_fromblogs, $tag, $post_notecount, $posts_since, $post_interval, $queue_status);
            $stmt->execute();
            $stmt->close();
          } else {
            $mode="append";
          }
      }
    }

    shuffle($result);
    for ($i = 1; $i <= $post_repeat; $i++) {
      saveposts_todb($result, $queuename);
    }
  
    if ($mode == "new") {
      $cmd     = '/opt/cpanel/ea-php56/root/usr/bin/php process.php ' . $queuename;
      ChromePhp::log($cmd);
      $process = new Process($cmd);
      $process->start();
      if ($process->status()) {
        ChromePhp::log("The process is currently running");
      } else {
        ChromePhp::log("The process is not running.");
      }
    }
  
    $data['success']    = true;
    $data['message']    = 'Success!';
  } else {
    $data['success'] = false;
    $data['errors']  = "Not exist";
  }
} else {
  $data['success'] = false;
  $data['errors']  = "Failed";
}

echo json_encode($data); exit;

function saveposts_todb($arr, $qname) {
  ChromePhp::log('Save to DB');
  $access_token  = $_SESSION['access_token'];
  $db     = DB::getInstance();
  $mysqli = $db->getConnection();
  $post_interval = intval($_POST['qinterval']);
  $blogname      = $_POST['blogname'];

  if (mysqli_connect_errno()) {
    printf("Connect failed: %s\n", mysqli_connect_error());
    exit();
  }
  if (isset($arr)) {
    foreach ($arr as $post) {
      $notecount = isset($post['note_count']) ? intval($post['note_count']) : 0;
      $blogType = $post['type'];

      switch ($blogType) {
        case 'text':
          $stmt      = $mysqli->prepare("INSERT INTO $qname (oauth_token, oauth_token_secret, post_interval, blogname, postid, reblog_key, type, notecount, title, body) VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?)");
          $stmt->bind_param('ssdssssdss', $access_token['oauth_token'], $access_token['oauth_token_secret'], $post_interval, $blogname, $post['id'], $post['reblog_key'], $blogType, $notecount, $post['title'], $post['body']);
          break;

        case 'audio':
          $stmt      = $mysqli->prepare("INSERT INTO $qname (oauth_token, oauth_token_secret, post_interval, blogname, postid, reblog_key, type, notecount, caption, external_url) VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?)");
          $stmt->bind_param('ssdssssdss', $access_token['oauth_token'], $access_token['oauth_token_secret'], $post_interval, $blogname, $post['id'], $post['reblog_key'], $blogType, $notecount, $post['caption'], $post['audio_source_url']);
          break;

        case 'video':
          $caption = "nothing";
          $stmt      = $mysqli->prepare("INSERT INTO $qname (oauth_token, oauth_token_secret, post_interval, blogname, postid, reblog_key, type, notecount, caption, embed) VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?)");
          $stmt->bind_param('ssdssssdss', $access_token['oauth_token'], $access_token['oauth_token_secret'], $post_interval, $blogname, $post['id'], $post['reblog_key'], $blogType, $notecount, $caption, $post['player']['0']['embed_code']);
          break;

        case 'quote':
          $stmt      = $mysqli->prepare("INSERT INTO $qname (oauth_token, oauth_token_secret, post_interval, blogname, postid, reblog_key, type, notecount, quote, source) VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?)");
          $stmt->bind_param('ssdssssdss', $access_token['oauth_token'], $access_token['oauth_token_secret'], $post_interval, $blogname, $post['id'], $post['reblog_key'], $blogType, $notecount, $post['text'], $post['source']);
          break;

        case 'link':
          $stmt      = $mysqli->prepare("INSERT INTO $qname (oauth_token, oauth_token_secret, post_interval, blogname, postid, reblog_key, type, notecount, title, url, description, thumbnail, author, excerpt) VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)");
          $stmt->bind_param('ssdssssdssssss', $access_token['oauth_token'], $access_token['oauth_token_secret'], $post_interval, $blogname, $post['id'], $post['reblog_key'], $blogType, $notecount, $post['title'], $post['url'], $post['description'], $post['photos']['0']['original_size']['url'], $post['author'], $post['excerpt']);
          break;

        case 'chat':
          $stmt      = $mysqli->prepare("INSERT INTO $qname (oauth_token, oauth_token_secret, post_interval, blogname, postid, reblog_key, type, notecount, title, conversation) VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?)");
          $stmt->bind_param('ssdssssdss', $access_token['oauth_token'], $access_token['oauth_token_secret'], $post_interval, $blogname, $post['id'], $post['reblog_key'], $blogType, $notecount, $post['title'], $post['body']);
          break;

        case 'photo':
          $stmt      = $mysqli->prepare("INSERT INTO $qname (oauth_token, oauth_token_secret, post_interval, blogname, postid, reblog_key, type, notecount, caption, source, link) VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)");
          $stmt->bind_param('ssdssssdsss', $access_token['oauth_token'], $access_token['oauth_token_secret'], $post_interval, $blogname, $post['id'], $post['reblog_key'], $blogType, $notecount, $post['caption'], $post['photos']['0']['original_size']['url'], $post['image_permalink']);
          break;

        case 'answer':
          break;

        default:
          break;
      }
      if ($blogType != 'answer') {
        $stmt->execute();
        $stmt->close();
      }
    }
  }
//   mysqli_close($mysqli);
}

?>